@@ -5,9 +5,10 @@
 # @FileName: __init__.py.py
 
 
-from .core import headers_format,fidder_to_python3
+from .core import headers_format,fidder_to_python3,get_html_text
 
 __all__ = (
     headers_format,
-    fidder_to_python3
+    fidder_to_python3,
+    get_html_text
 )
